@@ -28,9 +28,7 @@
 
 #include <stdbool.h>
 
-void gdgeoip2_init(void);
-
-F_NONNULLX(1,2,3)
-nlist_t* gdgeoip2_make_list(const char* pathname, const char* map_name, dclists_t* dclists, const dcmap_t* dcmap, const bool city_auto_mode, const bool city_no_region);
+F_NONNULLX(1, 2, 3)
+nlist_t* gdgeoip2_make_list(const char* pathname, const char* map_name, dclists_t* dclists, const dcmap_t* dcmap, const bool city_auto_mode);
 
 #endif // GDGEOIP2_H
