@@ -228,7 +228,6 @@ void dnspacket_wait_stats(const socks_cfg_t* socks_cfg)
 
 static dnsp_ctx_t* dnspacket_ctx_init(dnspacket_stats_t** stats_out, const bool is_udp, const bool udp_is_ipv6, const bool tcp_pad, const unsigned tcp_timeout_secs)
 {
-    dnsp_ctx_t* ctx = xcalloc(sizeof(*ctx));
     if (udp_is_ipv6)
         gdnsd_assert(is_udp);
     if (tcp_pad)
@@ -236,23 +235,24 @@ static dnsp_ctx_t* dnspacket_ctx_init(dnspacket_stats_t** stats_out, const bool
     if (tcp_timeout_secs)
         gdnsd_assert(!is_udp);
 
+    dnsp_ctx_t* ctx = xcalloc(sizeof(*ctx));
+    ctx->stats = *stats_out = xcalloc(sizeof(*ctx->stats));
+    ctx->dyn = xmalloc(gdnsd_result_get_alloc());
     gdnsd_rand32_init(&ctx->rand_state);
+    gdnsd_plugins_action_iothread_init();
+
     ctx->is_udp = is_udp;
+    ctx->stats->is_udp = is_udp;
     ctx->udp_edns_max = udp_is_ipv6 ? gcfg->max_edns_response_v6 : gcfg->max_edns_response;
     ctx->tcp_pad = tcp_pad;
     ctx->edns_tcp_keepalive = tcp_timeout_secs * 10;
     ctx->dso_inactivity = tcp_timeout_secs * 1000;
-    ctx->dyn = xmalloc(gdnsd_result_get_alloc());
-
-    gdnsd_plugins_action_iothread_init();
 
     pthread_mutex_lock(&stats_init_mutex);
-    ctx->stats = dnspacket_stats[stats_initialized++] = xcalloc(sizeof(*ctx->stats));
-    ctx->stats->is_udp = is_udp;
-    pthread_cond_signal(&stats_init_cond);
+    dnspacket_stats[stats_initialized++] = ctx->stats;
     pthread_mutex_unlock(&stats_init_mutex);
+    pthread_cond_signal(&stats_init_cond);
 
-    *stats_out = ctx->stats;
     return ctx;
 }
 
@@ -1364,8 +1364,8 @@ static unsigned encode_rr_soa(dnsp_ctx_t* ctx, unsigned offset, const ltree_rrse
 
     // fill in the rdata
     const unsigned rdata_offset = offset;
-    offset += store_dname_comp(&ctx->txn, rdata->master, offset, true);
-    offset += store_dname_comp(&ctx->txn, rdata->email, offset, false);
+    offset += store_dname_comp(&ctx->txn, rdata->mname, offset, true);
+    offset += store_dname_comp(&ctx->txn, rdata->rname, offset, false);
     memcpy(&packet[offset], &rdata->times, 20);
     offset += 20; // 5x 32-bits
 
@@ -2259,10 +2259,10 @@ unsigned process_dns_query(dnsp_ctx_t* ctx, const gdnsd_anysin_t* sa, pkt_t* pkt
     if (ctx->txn.edns.req_edns)
         res_offset = do_edns_output(ctx, pkt->raw, res_offset, status);
 
-    gdnsd_put_una16(htons(ctx->txn.qdcount), &hdr->qdcount);
-    gdnsd_put_una16(htons(ctx->txn.ancount + ctx->txn.cname_ancount), &hdr->ancount);
-    gdnsd_put_una16(htons(ctx->txn.nscount), &hdr->nscount);
-    gdnsd_put_una16(htons(ctx->txn.arcount), &hdr->arcount);
+    hdr->qdcount = htons(ctx->txn.qdcount);
+    hdr->ancount = htons(ctx->txn.ancount + ctx->txn.cname_ancount);
+    hdr->nscount = htons(ctx->txn.nscount);
+    hdr->arcount = htons(ctx->txn.arcount);
 
     gdnsd_assert(res_offset <= MAX_RESPONSE_BUF);
 
