@@ -20,24 +20,12 @@
 #ifndef GDNSD_ZSCAN_H
 #define GDNSD_ZSCAN_H
 
-#include "ztree.h"
+#include "ltree.h"
 
 #include <gdnsd/compiler.h>
 
-// Actually scan the zonefile, creating the data.  The failure type
-//   distinction is useful for the filesystem-level code over in
-//   zsrc_rfc1035.c in deciding whether and when to retry a failure.
-// FAILED_FILE means that something went wrong with filesystem-level
-//   operations (cannot open, lock, mmap, close, etc), whereas FAILED_PARSE
-//   means the contents were no good.
-
-typedef enum {
-    ZSCAN_RFC1035_SUCCESS = 0,
-    ZSCAN_RFC1035_FAILED_PARSE = 1,
-    ZSCAN_RFC1035_FAILED_FILE = 2,
-} zscan_rfc1035_status_t;
-
+// Actually scan the zonefile, creating the data.  A true retval means failure.
 F_NONNULL
-zscan_rfc1035_status_t zscan_rfc1035(zone_t* zone, const char* fn);
+bool zscan_rfc1035(zone_t* zone, const char* fn);
 
 #endif // GDNSD_ZSCAN_H
